## Data upload from packages

Examples of how to upload your local directory datasets into clarifai app datasets using data_upload utils `from_module` feature.

The `examples.py` script imports the data upload module and executes the upload of the IMDB_reviews text_classification and [food-101 image classification](https://data.vision.ee.ethz.ch/cvl/datasets_extra/food-101/) datasets by passing the package paths as a parameter in UploadConfig().
